@@ -14,10 +14,12 @@ def main():
     connector = RpcConnector(host=args.host, port=args.port, username=args.username, password=args.password)
 
     file_bytes = b"hello, this is a file"
-    response, files = connector.call_procedure("addition", {"a": 22, "b": 33}, {"file.txt": file_bytes})
+    r1 = connector.call_procedure("addition", {"a": 22, "b": 33}, {"file": file_bytes})
+    r2 = connector.call_procedure("multiply", {"a": 33, "b": 33}, {"file": file_bytes})
+    r3 = connector.call_procedure("addition", {"a": 234, "b": 33}, {"file": file_bytes})
+    r4 = connector.call_procedure("multiply", {"a": 22, "b": 33}, {"file": file_bytes})
 
-    print(response)
-    print(files)
+    print(r1[0], r2[0], r3[0], r4[0], r1[1], r2[1], r3[1], r4[1])
 
 
 if __name__ == "__main__":
