@@ -6,7 +6,13 @@ from FLF import RpcServer
 def addition(params, files):
     file_bytes = b"yes, this is response"
 
-    return {"response": params.get("a", 0) + params.get("b", 0)}, {"response.txt": file_bytes}
+    return {"response": "hello" + str(params["a"])}, {"file": file_bytes}
+
+
+def multiply(params, files):
+    file_bytes = b"yes, this is response"
+
+    return {"response": "hello" + str(params["a"] * 10)}, {"file": file_bytes}
 
 
 def default(params, files):
@@ -22,9 +28,8 @@ def main():
     args = parser.parse_args()
 
     app = RpcServer(host=args.host, port=args.port, username=args.username, password=args.password,
-                    procedures={"addition": addition, "default": default})
+                    procedures={"addition": addition, "multiply": multiply, "default": default})
 
 
 if __name__ == "__main__":
     main()
-
